@@ -3,6 +3,8 @@
 module Sound.SFML.LowLevel where
 
 
+import Control.Applicative
+
 import Foreign.Ptr
 import Foreign.C.String
 
@@ -30,8 +32,27 @@ foreign import ccall sfSound_SetBuffer :: Ptr Sound -> Ptr SoundBuffer -> IO ()
 
 foreign import ccall sfSound_Play :: Ptr Sound -> IO ()
 
+foreign import ccall sfSound_Stop :: Ptr Sound -> IO ()
+
 foreign import ccall sfSound_Destroy :: Ptr Sound -> IO ()
 
+foreign import ccall sfSound_SetLoop :: Ptr Sound -> Bool -> IO ()
+
+foreign import ccall sfSound_SetVolume :: Ptr Sound -> Float -> IO ()
+
+foreign import ccall sfSound_GetStatus :: Ptr Sound -> IO Int
+
+getStatus s = toStatus <$> sfSound_GetStatus s
+
+toStatus :: Int -> Status
+toStatus = toEnum
+
+data Status
+    = Stopped
+    | Paused
+    | Playing
+  deriving (Eq, Enum, Show)
+
 
 -- * Music
 
